<?php

// $Id: xspf_playlist.cck.inc,v 1.1.2.1 2010/09/09 03:03:19 arthuregg Exp $


/**
 * Implements cck fields as a source for XSPF content
 *
 * @param $sources
 *   Array, sources that can build playlists
 * @param $content_type
 *   String, content type name
 */
function xspf_playlist_file_sources_cck(&$sources, $content_type) {
  $type = content_types($content_type);
  if ($fields = $type['fields']) {
    foreach ($fields as $field) {
      if (in_array($field['type'], array('text', 'image', 'filefield', 'file_video', 'video_cck', 'emvideo'))) {
        $sources['xspf--cck--' . $field['field_name']] = t('CCK: !label', array('!label' => $field['widget']['label']));
      }
    }
  }
}


/**
 * Implements cck fields as a source for XSPF content
 *
 * @param $sources
 *   Array, sources that can build playlists
 * @param $content_type
 *   String, content type name
 */
function xspf_playlist_thumb_sources_cck(&$sources, $content_type) {
  $type = content_types($content_type);
  if ($fields = $type['fields']) {
    foreach ($fields as $field) {
      if (in_array($field['type'], array('image', 'filefield'))) {
        $sources['xspf--cck--' . $field['field_name']] = t('CCK: !label', array('!label' => $field['widget']['label']));
      }
    }
  }
}


/**
 * Provides cck fields
 *
 * @param $items
 * @param $node
 * @param $source_type
 */
function xspf_playlist_node_source_cck(&$items, $node, $source_type) {
  // Get the fields for this content type
  $type = content_types($node->type);
  if ($fields = $type['fields']) {
    foreach ($fields as $field) {
      // Is this field enabled?
      if ($field['field_name'] == $source_type) {
        // Get the handler function
        $function = 'xspf_playlist_cck_'. $field['type'] .'_handler';
        if (function_exists($function)) {
          $function($items, $node, $field['field_name']);
        }
      }
    }
  }
}


/**
 * Handles the emfield video field type
 *
 * @param $items
 * @param $node
 * @param $field_name
 */
function xspf_playlist_cck_video_cck_handler(&$items, $node, $field_name) {
  $items = array();
  // extract all the embeded items from this field
  foreach ($node->{$field_name} as $field) {
    if ($field['data']['flash']['url']) {
      if ($xspf_item = xspf_playlist_node_build_item($node, $field['data']['flash']['url'])) {
        $items[] = $xspf_item;
      }
    }
  }
}


/**
 * Handles the image field type
 *
 * @param $items
 * @param $node
 * @param $field_name
 */
function xspf_playlist_cck_image_handler(&$items, $node, $field_name) {
  $items = array();
  // extract all the embeded items from this field
  foreach ($node->{$field_name} as $field) {
    if ($field['filepath']) {
      if ($xspf_item = xspf_playlist_node_build_item($node, $field['filepath'])) {
        $items[] = $xspf_item;
      }
    }
  }
}


/**
 * Handles the text field type
 *
 * @param $items
 * @param $node
 * @param $field_name
 */
function xspf_playlist_cck_text_handler(&$items, $node, $field_name) {
  $items = array();
  // extract all the embeded items from this field
  foreach ($node->{$field_name} as $field) {
    if ($field['value']) {
      if ($xspf_item = xspf_playlist_node_build_item($node, $field['value'])) {
        $items[] = $xspf_item;
      }
    }
  }
}


/**
 * Handles the file field type
 *
 * @param $items
 * @param $node
 * @param $field_name
 */
function xspf_playlist_cck_filefield_handler(&$items, $node, $field_name) {
  // Extract all the embeded items from this field
  foreach ($node->{$field_name} as $field) {
    if ($field['filepath']) {
      if ($xspf_item = xspf_playlist_node_build_item($node, file_create_url($field['filepath']))) {
        $items[] = $xspf_item;
      }
    }
  }
}


/**
 * Handles the Embedded Video Field (emfield) type
 *
 * @param $items
 * @param $node
 * @param $field_name
 */
function xspf_playlist_cck_emvideo_handler(&$items, $node, $field_name) {
  $items = array();
  // extract all the embeded items from this field
  foreach ($node->{$field_name} as $field) {
    if ($field['value'] && $field['provider']) {
      if ($xspf_item = xspf_playlist_node_build_item($node, emfield_include_invoke('emvideo', $field['provider'], 'embedded_link', $field['value'], $field['data']))) {
        $items[] = $xspf_item;
      }
    }
  }
}


/**
 * Returns thumbnails from specified fields
 * @param unknown_type $thumbs
 * @param unknown_type $node
 * @param unknown_type $identifier
 */
function xspf_playlist_node_thumb_cck(&$thumbs, $node, $identifier) {
  // Does this node have the identified field name?
  if ($node->{$identifier}) {
    // Extract all the embeded items from this field
    foreach ($node->{$identifier} as $field) {
      if ($field['filepath']) {
        // check the mime type of the file
        if (strstr($field['filemime'], 'image')) {
          $thumbs[] = $field['filepath'];
        }
      }
    }
  }
}