<?php

// $Id: xspf_playlist.node.inc,v 1.1.2.1 2010/09/09 03:03:19 arthuregg Exp $

/**
 * @file
 * Provides basic node services
 */


/**
 * Landing page for producing the XSPF data for a given node- node/X/xspf
 *
 * @param $node
 *   Object, Drupal node
 * @return string
 *   XSPF XML
 */
function xspf_playlist_node_view($node) {
  // Are playlists enabled on this node type?
  if (variable_get('xspf_playlist_enabled_type_' . $node->type, FALSE)) {
    $items = array();
    drupal_alter('xspf_node_items', $items, $node);
    // Do we have anything to display?
    if ($items) {
      xspf_playlist_render($items);
    }
  }
  // No content found.
  return drupal_not_found();
}


/**
 * Builds a XSPF track entry data structure for nodes
 *
 * @param $node
 *   object, node
 * @param $filepath
 *   String, url to file that is being added to the items array
 */
function xspf_playlist_node_build_item($node, $filepath) {
  $item = array();
  $item[] = array(
    'key' => 'location',
    'value' => $filepath,
  );
  // Link to playlist item
  $item[] = array(
    'key' => 'info',
    'value' => xspf_playlist_url('node/'. $node->nid),
  );
  // we need to see if we need to set the duration tag
  if (in_array(strtolower($type), array('jpg', 'gif', 'png'))) {
    $item[] = array(
      'key' => 'duration',
      'value' => variable_get('xspf_playlist_duration_'. $node->type, 10),
    );
  }
  $item[] = array(
    'key' => 'title',
    'value' => check_plain($node->title),
  );
  $item[] = array(
    'key' => 'identifier',
    'value' => $node->nid,
  );
  // Allow the build item to be altered
  drupal_alter('xspf_node_playlist_item', $item, $node);
  return $item;
}