<?php

// $Id: xspf_playlist.upload.inc,v 1.1.2.1 2010/09/09 03:03:19 arthuregg Exp $


/**
 * Implements the upload module as a source for XSPF content
 *
 * @param $sources
 *   Array, sources that can build playlists
 * @param $content_type
 *   String, content type name
 */
function xspf_playlist_file_sources_upload(&$sources, $content_type) {
  $sources['xspf--upload--upload'] = t('Drupal file attachments');
}


/**
 * Implements the upload module as a thumbnail for XSPF content
 *
 * @param $sources
 *   Array, sources that can build playlists
 * @param $content_type
 *   String, content type name
 */
function xspf_playlist_thumb_sources_upload(&$sources, $content_type) {
  $sources['xspf--upload--upload'] = t('Drupal file attachments');
}


/**
 * Provides files uploaded with drupal's upload module
 *
 * @param $items
 * @param $node
 * @param $source_type
 */
function xspf_playlist_node_source_upload(&$items, $node, $source_type) {
  // Loop through files
  if (isset($node->files)) {
    foreach ($node->files as $file) {
      if ($item = xspf_playlist_upload_file($file, $node)) {
        $items[] = $item;
      }
    }
  }
}


/**
 * Create a generic item from a Drupal file and node
 *
 * @param $file
 * @param $node
 * @return xspf item
 */
function xspf_playlist_upload_file($file, $node) {
  // Is this file type supported?
  if (xspf_playlist_filetype_supported($file->filepath)) {
    // Create the item
    $item = xspf_playlist_node_build_item($node, file_create_url($file->filepath));
    // Set the title to the file name description only if it is different than
    // the file name to force the description to be human set
    if (isset($file->description) && ($file->description != $file->filename )) {
      xspf_playlist_item_set_value($item, array('key' => 'title', 'value' => check_plain($file->description)), FALSE);
    }
    // Get the mime type for this file
    $mime = file_get_mimetype($file->filepath);
    $mime = explode('/', $mime);
    $mime = $mime[0];
    // Is this a useable type?
    if (in_array($mime, array('image', 'video', 'audio'))) {
      xspf_playlist_item_set_value($item, array('key' => 'type', 'value' => $mime));
    }
    return $item;
  }
}


/**
 * Returns any images uploaded on the node
 * @param unknown_type $thumbs
 * @param unknown_type $node
 * @param unknown_type $identifier
 */
function xspf_playlist_node_thumb_upload(&$thumbs, $node, $identifier) {
  if ($node->files) {
    foreach($node->files as $file) {
      // Check the mime type of the file
      if (strstr($file->filemime, 'image')) {
        $thumbs[] = $file->filepath;
      }
    }
  }
}